@@ -2,4 +2,5 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-pref("app.update.channel", "default");
+//@line 6 "/build/firefox/src/firefox-58.0/browser/app/profile/channel-prefs.js"
+pref("app.update.channel", "release");
